==> haskell-tagstream-conduit-0.5.6-476-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tagstream-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tagstream-conduit
version:              0.5.6
visibility:           public
id:                   tagstream-conduit-0.5.6-4GJc4TzKqJIkwwnREDAZn
key:                  tagstream-conduit-0.5.6-4GJc4TzKqJIkwwnREDAZn
license:              BSD-3-Clause
maintainer:           yi.codeplayer@gmail.com
author:               yihuang
homepage:             http://github.com/yihuang/tagstream-conduit
synopsis:             streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.

category:             Web, Conduit
abi:                  e6f5b2846a86a9d05bfd5be5a4c43afb
exposed:              True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Entities Text.HTML.TagStream.Text
    Text.HTML.TagStream.Types Text.HTML.TagStream.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tagstream-conduit-0.5.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tagstream-conduit-0.5.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tagstream-conduit-0.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tagstream-conduit
hs-libraries:         HStagstream-conduit-0.5.6-4GJc4TzKqJIkwwnREDAZn
depends:
    attoparsec-0.14.4-AS2Ju05FAjs55rPAuL3miO base-4.17.2.1
    blaze-builder-0.4.4-9TwQ27zteac6dzdX8WGk7W bytestring-0.11.5.3
    case-insensitive-1.2.1.0-1RHeXy1S6Rm5Spie3OUbmD
    conduit-1.3.6.1-B7V1OlOMAuaARuDzpB8NsU
    conduit-extra-1.3.8-HPIe52rZrj4DPVo2Z9t0LA
    data-default-0.7.1.2-8yRIq8kwMNHG7OFJsT5Ayy
    resourcet-1.2.6-7pcZOXyYp3bA9FS4E6qwzr text-2.0.2
    transformers-0.5.6.2 xml-conduit-1.9.1.4-LxAekl344qnWwC42iOmCn

haddock-interfaces:
    /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock

haddock-html:         /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tagstream-conduit-0.5.6-477-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tagstream-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tagstream-conduit
version:              0.5.6
visibility:           public
id:                   tagstream-conduit-0.5.6-BfjPKZDOETGGxeYiaCfJ6w
key:                  tagstream-conduit-0.5.6-BfjPKZDOETGGxeYiaCfJ6w
license:              BSD-3-Clause
maintainer:           yi.codeplayer@gmail.com
author:               yihuang
homepage:             http://github.com/yihuang/tagstream-conduit
synopsis:             streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.

category:             Web, Conduit
abi:                  1e52f82fcefa4968cbb0b4552557e28b
exposed:              True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Entities Text.HTML.TagStream.Text
    Text.HTML.TagStream.Types Text.HTML.TagStream.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tagstream-conduit-0.5.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tagstream-conduit-0.5.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tagstream-conduit-0.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tagstream-conduit
hs-libraries:         HStagstream-conduit-0.5.6-BfjPKZDOETGGxeYiaCfJ6w
depends:
    attoparsec-0.14.4-BOYjI7Xnyxi2UxSSzbjWOG base-4.17.2.1
    blaze-builder-0.4.4-Lx3iAaL3SPqLsOeZbYO5TI bytestring-0.11.5.3
    case-insensitive-1.2.1.0-DJzIJZH4DdL5KuISGpY4ML
    conduit-1.3.6.1-106afLHctvQ8RMVwlIAuXV
    conduit-extra-1.3.8-H8VbVpHwFEnEcdjiRo0ORI
    data-default-0.7.1.2-8yRIq8kwMNHG7OFJsT5Ayy
    resourcet-1.2.6-JgWdYDiOmbEL6WqMsj6qcd text-2.0.2
    transformers-0.5.6.2 xml-conduit-1.9.1.4-2J0zZfr9vqgEeegk8Odyfb

haddock-interfaces:
    /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock

haddock-html:         /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
